@@ -15,7 +15,6 @@
 import collections
 import copy
 import datetime
-import warnings
 
 from oslo_config import cfg
 from oslo_context import context as oslo_context
@@ -107,15 +106,13 @@ class ContextBase(oslo_context.RequestContext):
 
     @classmethod
     def from_dict(cls, values):
-        return cls(user_id=values.get('user_id', values.get('user')),
-                   tenant_id=values.get('tenant_id', values.get('project_id')),
-                   is_admin=values.get('is_admin'),
-                   roles=values.get('roles'),
-                   timestamp=values.get('timestamp'),
-                   request_id=values.get('request_id'),
-                   tenant_name=values.get('tenant_name'),
-                   user_name=values.get('user_name'),
-                   auth_token=values.get('auth_token'))
+        cls_obj = super().from_dict(values)
+        if values.get('timestamp'):
+            cls_obj.timestamp = values['timestamp']
+        cls_obj.user_id = values.get('user_id', values.get('user'))
+        cls_obj.tenant_id = values.get('tenant_id', values.get('project_id'))
+        cls_obj.tenant_name = values.get('tenant_name')
+        return cls_obj
 
     def elevated(self):
         """Return a version of this context with admin flag set."""
@@ -125,7 +122,7 @@ class ContextBase(oslo_context.RequestContext):
         if 'admin' not in [x.lower() for x in context.roles]:
             context.roles = context.roles + ["admin"]
 
-        if cfg.CONF.oslo_policy.enforce_new_defaults:
+        if cfg.CONF.oslo_policy.enforce_scope:
             context.system_scope = 'all'
 
         return context
@@ -148,18 +145,17 @@ class Context(ContextBaseWithSession):
 
     @property
     def session(self):
-        # TODO(akamyshnikova): checking for session attribute won't be needed
-        # when reader and writer will be used
+        # TODO(ralonsoh): "Context.session" is provided by
+        # "enginefacade.transaction_context_provider" when a new transaction,
+        # READER or WRITER, is created. This property is just a temporary fix
+        # for those transactions that are not executed inside a transaction.
+        # By manually selecting the type of transaction we can speed up the
+        # code because by default a writer session is always created, even
+        # within read only operations.
         if hasattr(super(), 'session'):
-            if self._session:
-                warnings.warn('context.session is used with and without '
-                              'new enginefacade. Please update the code to '
-                              'use new enginefacede consistently.',
-                              DeprecationWarning)
-            return super().session
+            self._session = super().session
         if self._session is None:
             self._session = db_api.get_writer_session()
-
         return self._session
 
     def set_transaction_constraint(self, resource, resource_id, rev_number):
