@@ -87,6 +87,27 @@ class TestNeutronContext(_base.BaseTestCase):
         self.assertEqual(owner['user_id'], ctx.user_id)
         self.assertEqual(owner['tenant_id'], ctx.tenant_id)
 
+    def test_neutron_context_from_dict_validate(self):
+        ctx = context.Context(user_id='user_id1',
+                              user_name='user',
+                              tenant_id='tenant_id1',
+                              tenant_name='project1',
+                              request_id='request_id1',
+                              auth_token='auth_token1')
+        values = {'user_id': 'user_id1',
+                  'user_name': 'user',
+                  'tenant_id': 'tenant_id1',
+                  'tenant_name': 'project1',
+                  'request_id': 'request_id1',
+                  'auth_token': 'auth_token1'}
+        ctx2 = context.Context.from_dict(values)
+
+        ctx_dict = ctx.to_dict()
+        ctx_dict.pop('timestamp')
+        ctx2_dict = ctx2.to_dict()
+        ctx2_dict.pop('timestamp')
+        self.assertEqual(ctx_dict, ctx2_dict)
+
     def test_neutron_context_to_dict(self):
         ctx = context.Context('user_id', 'tenant_id')
         ctx_dict = ctx.to_dict()
@@ -151,8 +172,7 @@ class TestNeutronContext(_base.BaseTestCase):
         self.assertTrue(elevated2_ctx.is_admin)
 
     def test_neutron_context_elevated_system_scope_for_new_policies(self):
-        cfg.CONF.set_override(
-            'enforce_new_defaults', True, group='oslo_policy')
+        cfg.CONF.set_override('enforce_scope', True, group='oslo_policy')
         ctx = context.Context('user_id', 'tenant_id')
         self.assertFalse(ctx.is_admin)
         self.assertNotEqual('all', ctx.system_scope)
